@@ -2,11 +2,11 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021, by Samuel Williams.
+# Copyright, 2021-2024, by Samuel Williams.
 
-require 'io/event'
-require 'fiber'
-require 'benchmark'
+require "io/event"
+require "fiber"
+require "benchmark"
 
 Thread.report_on_exception = true
 
